==> yap_6.2.2.orig.tar.gz: yap-6.2.2/library/dialect/swi/INDEX.pl <==
index(write_to_chars,2,system,library(dialect/swi)).
index(read_from_chars,2,system,library(dialect/swi)).
index(append,2,system,library(dialect/swi)).
index(append,3,system,library(dialect/swi)).
index(delete,3,system,library(dialect/swi)).
index(member,2,system,library(dialect/swi)).
index(flatten,2,system,library(dialect/swi)).
index(intersection,3,system,library(dialect/swi)).
index(last,2,system,library(dialect/swi)).
index(memberchk,2,system,library(dialect/swi)).
index(max_list,2,system,library(dialect/swi)).
index(min_list,2,system,library(dialect/swi)).
index(nextto,3,system,library(dialect/swi)).
index(permutation,2,system,library(dialect/swi)).
index(reverse,2,system,library(dialect/swi)).
index(select,3,system,library(dialect/swi)).
index(selectchk,3,system,library(dialect/swi)).
index(sublist,2,system,library(dialect/swi)).
index(sumlist,2,system,library(dialect/swi)).
index(nth1,3,system,library(dialect/swi)).
index(nth0,3,system,library(dialect/swi)).
index(maplist,2,system,library(dialect/swi)).
index(maplist,3,system,library(dialect/swi)).
index(maplist,4,system,library(dialect/swi)).
index(maplist,5,system,library(dialect/swi)).
index(include,3,system,library(dialect/swi)).
index(exclude,3,system,library(dialect/swi)).
index(partition,4,system,library(dialect/swi)).
index(partition,5,system,library(dialect/swi)).
index(datime,1,system,library(dialect/swi)).
index(mktime,2,system,library(dialect/swi)).
index(file_property,2,system,library(dialect/swi)).
index(sleep,1,system,library(dialect/swi)).
index(genarg,3,system,library(dialect/swi)).
index(subsumes,2,system,library(dialect/swi)).
index(subsumes_chk,2,system,library(dialect/swi)).
index(term_hash,2,system,library(dialect/swi)).
index(unifiable,3,system,library(dialect/swi)).
index(cyclic_term,1,system,library(dialect/swi)).
index(variant,2,system,library(dialect/swi)).
index(concat_atom,2,system,library(dialect/swi)).
index(concat_atom,3,system,library(dialect/swi)).
index(setenv,2,system,library(dialect/swi)).
index(prolog_to_os_filename,2,system,library(dialect/swi)).
index(is_absolute_file_name,1,system,library(dialect/swi)).
index(read_clause,1,system,library(dialect/swi)).
index(string,1,system,library(dialect/swi)).
index(working_directory,2,system,library(dialect/swi)).
index(chdir,1,system,library(dialect/swi)).
index(compile_aux_clauses,1,system,library(dialect/swi)).
index(convert_time,2,system,library(dialect/swi)).
index('$set_source_module',2,system,library(dialect/swi)).
index('$declare_module',5,system,library(dialect/swi)).
index('$set_predicate_attribute',3,system,library(dialect/swi)).
index(time_file,2,system,library(dialect/swi)).
index(flag,3,system,library(dialect/swi)).
index(current_flag,1,system,library(dialect/swi)).

==> yap-6.3.3.tar.gz: yap-6.3.3/library/dialect/swi/INDEX.pl <==
index(write_to_chars,2,system,library(dialect/swi)).
index(read_from_chars,2,system,library(dialect/swi)).
index(append,2,system,library(dialect/swi)).
index(append,3,system,library(dialect/swi)).
index(delete,3,system,library(dialect/swi)).
index(member,2,system,library(dialect/swi)).
index(flatten,2,system,library(dialect/swi)).
index(intersection,3,system,library(dialect/swi)).
index(last,2,system,library(dialect/swi)).
index(memberchk,2,system,library(dialect/swi)).
index(max_list,2,system,library(dialect/swi)).
index(min_list,2,system,library(dialect/swi)).
index(nextto,3,system,library(dialect/swi)).
index(permutation,2,system,library(dialect/swi)).
index(reverse,2,system,library(dialect/swi)).
index(select,3,system,library(dialect/swi)).
index(selectchk,3,system,library(dialect/swi)).
index(sublist,2,system,library(dialect/swi)).
index(sumlist,2,system,library(dialect/swi)).
index(nth1,3,system,library(dialect/swi)).
index(nth0,3,system,library(dialect/swi)).
index(maplist,2,system,library(dialect/swi)).
index(maplist,3,system,library(dialect/swi)).
index(maplist,4,system,library(dialect/swi)).
index(maplist,5,system,library(dialect/swi)).
index(include,3,system,library(dialect/swi)).
index(exclude,3,system,library(dialect/swi)).
index(partition,4,system,library(dialect/swi)).
index(partition,5,system,library(dialect/swi)).
index(datime,1,system,library(dialect/swi)).
index(mktime,2,system,library(dialect/swi)).
index(file_property,2,system,library(dialect/swi)).
index(delete_file,1,system,library(dialect/swi)).
index(genarg,3,system,library(dialect/swi)).
index(subsumes,2,system,library(dialect/swi)).
index(subsumes_chk,2,system,library(dialect/swi)).
index(term_hash,2,system,library(dialect/swi)).
index(unifiable,3,system,library(dialect/swi)).
index(cyclic_term,1,system,library(dialect/swi)).
index(variant,2,system,library(dialect/swi)).
index(concat_atom,2,system,library(dialect/swi)).
index(concat_atom,3,system,library(dialect/swi)).
index(setenv,2,system,library(dialect/swi)).
index(read_clause,1,system,library(dialect/swi)).
index(string,1,system,library(dialect/swi)).
index(chdir,1,system,library(dialect/swi)).
index(compile_aux_clauses,1,system,library(dialect/swi)).
index(convert_time,2,system,library(dialect/swi)).
index('$set_source_module',2,system,library(dialect/swi)).
index('$declare_module',5,system,library(dialect/swi)).
index('$set_predicate_attribute',3,system,library(dialect/swi)).
index(stamp_date_time,3,system,library(dialect/swi)).
index(date_time_stamp,2,system,library(dialect/swi)).
index(format_time,3,system,library(dialect/swi)).
index(format_time,4,system,library(dialect/swi)).
index(time_file,2,system,library(dialect/swi)).
index(flag,3,system,library(dialect/swi)).
index(require,1,system,library(dialect/swi)).
index(normalize_space,2,system,library(dialect/swi)).
index(current_flag,1,system,library(dialect/swi)).
